@@ -70,7 +70,9 @@ class DOCUMENTUM_API():
         """
 
         if response.status_code in [200]:
-            if raw:
+            if response.status_code == 204:
+                return {'message': 'Record deleted successfully'}, response.status_code
+            elif raw:
                 return response.raw, response.status_code
             elif content:
                 return response.content, response.status_code
